@@ -31,3 +31,6 @@
 #include <ostree-bootconfig-parser.h>
 #include <ostree-diff.h>
 #include <ostree-gpg-verify-result.h>
+
+#include <ostree-autocleanups.h>
+#include <ostree-version.h>
